@@ -30,10 +30,6 @@
 #include "umlattributelist.h"
 #include "umloperationlist.h"
 
-// kde includes
-#if QT_VERSION < 0x050000
-#include <kdialog.h>
-#endif
 #include <KLocalizedString>
 #include <KMessageBox>
 
@@ -118,7 +114,7 @@ CodeDocument * CodeGenerator::findCodeDocumentByID(const QString &tag)
         return doc;
     }
     else {
-        return NULL;
+        return 0;
     }
 }
 
@@ -175,22 +171,11 @@ CodeDocumentList * CodeGenerator::getCodeDocumentList()
     return &m_codedocumentVector;
 }
 
-// the vanilla version
-
-/**
- * Get the editing dialog for this code document.
- */
-CodeViewerDialog * CodeGenerator::getCodeViewerDialog(QWidget* parent, CodeDocument *doc,
-        Settings::CodeViewerState & state)
-{
-    return new CodeViewerDialog(parent, doc, state);
-}
-
 /**
  * Load codegenerator data from xmi.
  * @param qElement   the element from which to load
  */
-void CodeGenerator::loadFromXMI(QDomElement & qElement)
+void CodeGenerator::loadFromXMI1(QDomElement & qElement)
 {
     // look for our particular child element
     QDomNode node = qElement.firstChild();
@@ -214,7 +199,7 @@ void CodeGenerator::loadFromXMI(QDomElement & qElement)
         else if (docTag == QLatin1String("codedocument") || docTag == QLatin1String("classifiercodedocument")) {
             CodeDocument * codeDoc = findCodeDocumentByID(id);
             if (codeDoc) {
-                codeDoc->loadFromXMI(codeDocElement);
+                codeDoc->loadFromXMI1(codeDocElement);
             }
             else {
                 uWarning() << "missing code document for id:" << id;
@@ -242,7 +227,7 @@ void CodeGenerator::loadCodeForOperation(const QString& idStr, const QDomElement
 
         UMLObject::ObjectType t = obj->baseType();
         if (t == UMLObject::ot_Operation) {
-            UMLOperation *op = static_cast<UMLOperation*>(obj);
+            UMLOperation *op = obj->asUMLOperation();
             op->setSourceCode(value);
         }
         else {
@@ -257,7 +242,7 @@ void CodeGenerator::loadCodeForOperation(const QString& idStr, const QDomElement
 /**
  * Save the XMI representation of this object
  */
-void CodeGenerator::saveToXMI(QDomDocument & doc, QDomElement & root)
+void CodeGenerator::saveToXMI1(QDomDocument & doc, QDomElement & root)
 {
     QString langType = Uml::ProgrammingLanguage::toString(language());
     QDomElement docElement = doc.createElement(QLatin1String("codegenerator"));
@@ -285,43 +270,12 @@ void CodeGenerator::saveToXMI(QDomDocument & doc, QDomElement & root)
         CodeDocumentList::const_iterator it = docList->begin();
         CodeDocumentList::const_iterator end = docList->end();
         for (; it != end; ++it) {
-            (*it)->saveToXMI(doc, docElement);
+            (*it)->saveToXMI1(doc, docElement);
         }
     }
     root.appendChild(docElement);
 }
 
-/**
- * Initialize this code generator from its parent UMLDoc. When this is called,
- * it will (re-)generate the list of code documents for this project (generator)
- * by checking for new objects/attributes which have been added or changed in the
- * document. One or more CodeDocuments will be created/overwritten/amended as is
- * appropriate for the given language.
- * <p>
- * In this 'generic' version a ClassifierCodeDocument will exist for each and
- * every classifier that exists in our UMLDoc. IF when this is called, a code document
- * doesn't exist for the given classifier, then we will created and add a new code
- * document to our generator.
- * <p>
- * IF you want to add non-classifier related code documents at this step,
- * you will need to overload this method in the appropriate
- * code generatator (see JavaCodeGenerator for an example of this).
- */
-void CodeGenerator::initFromParentDocument()
-{
-    // Walk through the document converting classifiers into
-    // classifier code documents as needed (e.g only if doesn't exist)
-    UMLClassifierList concepts = m_document->classesAndInterfaces();
-    foreach (UMLClassifier *c, concepts) {
-        // Doesn't exist? Then build one.
-        CodeDocument * codeDoc = findCodeDocumentByClassifier(c);
-        if (!codeDoc) {
-            codeDoc = newClassifierCodeDocument(c);
-            addCodeDocument(codeDoc); // this will also add a unique tag to the code document
-        }
-    }
-}
-
 /**
  * Force a synchronize of this code generator, and its present contents, to that of the parent UMLDocument.
  * "UserGenerated" code will be preserved, but Autogenerated contents will be updated/replaced
@@ -336,43 +290,6 @@ void CodeGenerator::syncCodeToDocument()
     }
 }
 
-// in this 'vanilla' version, we only worry about adding classifier
-// documents
-
-/**
- * This function checks for adding objects to the UMLDocument.
- */
-void CodeGenerator::checkAddUMLObject(UMLObject * obj)
-{
-    if (!obj) {
-        return;
-    }
-
-    UMLClassifier * c = dynamic_cast<UMLClassifier*>(obj);
-    if (c) {
-        CodeDocument * cDoc = newClassifierCodeDocument(c);
-        addCodeDocument(cDoc);
-    }
-}
-
-/**
- * This function checks for removing objects from the UMLDocument.
- */
-void CodeGenerator::checkRemoveUMLObject(UMLObject * obj)
-{
-    if (!obj) {
-        return;
-    }
-
-    UMLClassifier * c = dynamic_cast<UMLClassifier*>(obj);
-    if (c) {
-        ClassifierCodeDocument * cDoc = (ClassifierCodeDocument*) findCodeDocumentByClassifier(c);
-        if (cDoc) {
-            removeCodeDocument(cDoc);
-        }
-    }
-}
-
 /**
  * Find a code document by the given classifier.
  * NOTE: FIX, this should be 'protected' or we could have problems with CPP code generator
@@ -468,16 +385,6 @@ void CodeGenerator::finalizeRun()
 {
 }
 
-/**
- * Create a new Code document belonging to this package.
- * @return CodeDocument   pointer to new code document.
- */
-CodeDocument * CodeGenerator::newCodeDocument()
-{
-    CodeDocument * newCodeDoc = new CodeDocument();
-    return newCodeDoc;
-}
-
 /**
  *  Gets the heading file (as a string) to be inserted at the
  *  beginning of the generated file. you give the file type as
@@ -735,7 +642,7 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
                 UMLObject *objA = a->getObject(Uml::RoleType::A);
                 UMLObject *objB = a->getObject(Uml::RoleType::B);
                 if (objA == c) {
-                    temp = static_cast<UMLPackage*>(objB);
+                    temp = objB->asUMLPackage();
                 }
             }
             break;
@@ -745,8 +652,8 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
             {
                 UMLObject *objA = a->getObject(Uml::RoleType::A);
                 UMLObject *objB = a->getObject(Uml::RoleType::B);
-                if (objA == c && objB->baseType() != UMLObject::ot_Datatype) {
-                    temp = static_cast<UMLPackage*>(objB);
+                if (objA == c && !objB->isUMLDatatype()) {
+                    temp = objB->asUMLPackage();
                 }
             }
             break;
@@ -766,14 +673,14 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
         temp = 0;
         //check return value
         temp = (UMLClassifier*) op->getType();
-        if (temp && temp->baseType() != UMLObject::ot_Datatype && !cList.count(temp)) {
+        if (temp && !temp->isUMLDatatype() && !cList.count(temp)) {
             cList.append(temp);
         }
         //check parameters
         UMLAttributeList atl = op->getParmList();
         foreach(UMLAttribute *at, atl) {
             temp = (UMLClassifier*)at->getType();
-            if (temp && temp->baseType() != UMLObject::ot_Datatype && !cList.count(temp)) {
+            if (temp && !temp->isUMLDatatype() && !cList.count(temp)) {
                 cList.append(temp);
             }
         }
@@ -785,7 +692,7 @@ void CodeGenerator::findObjectsRelated(UMLClassifier *c, UMLPackageList &cList)
         foreach (UMLAttribute *at, atl) {
             temp=0;
             temp = (UMLClassifier*) at->getType();
-            if (temp && temp->baseType() != UMLObject::ot_Datatype && !cList.count(temp)) {
+            if (temp && !temp->isUMLDatatype() && !cList.count(temp)) {
                 cList.append(temp);
             }
         }
@@ -845,22 +752,6 @@ QString CodeGenerator::formatSourceCode(const QString& code, const QString& inde
     return output;
 }
 
-/**
- * Connect additional slots.
- * Only required for Advanced Code Generators.
- * To be called after constructing the code generator (see CodeGenFactory).
- */
-void CodeGenerator::connect_newcodegen_slots()
-{
-    connect(m_document, SIGNAL(sigObjectCreated(UMLObject*)),
-            this, SLOT(checkAddUMLObject(UMLObject*)));
-    connect(m_document, SIGNAL(sigObjectRemoved(UMLObject*)),
-            this, SLOT(checkRemoveUMLObject(UMLObject*)));
-    CodeGenerationPolicy *commonPolicy = UMLApp::app()->commonPolicy();
-    connect(commonPolicy, SIGNAL(modifiedCodeContent()),
-            this, SLOT(syncCodeToDocument()));
-}
-
 // these are utility methods for accessing the default
 // code gen policy object and should go away when we
 // finally implement the CodeGenDialog class -b.t.
@@ -925,4 +816,3 @@ void CodeGenerator::createDefaultStereotypes()
     //empty by default, override in your code generator
     //e.g.  m_document->createDefaultStereotypes("constructor");
 }
-
