@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2013                                               *
+ *   copyright (C) 2002-2015                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -12,30 +12,27 @@
 #define NOTEDIALOG_H
 
 // kde includes
-#include <kdialog.h>
+#include "singlepagedialogbase.h"
 
+class DocumentationWidget;
 class NoteWidget;
-class KTextEdit;
-class QGroupBox;
 
 /**
  * @author Paul Hensgen
  * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
  */
-class NoteDialog : public KDialog
+class NoteDialog : public SinglePageDialogBase
 {
    Q_OBJECT
 public:
-    NoteDialog(QWidget * parent, NoteWidget * pNote);
+    NoteDialog(QWidget *parent, NoteWidget *note);
     ~NoteDialog();
 
-public slots:
-    void slotOk();
+protected:
+    DocumentationWidget *m_docWidget; ///< widget holding the documentation
+    NoteWidget *m_noteWidget;  ///< note widget to show documentation for
 
-private:
-    QGroupBox * m_docGB;  ///< GUI widget
-    KTextEdit * m_docTE;  ///< GUI widget
-    NoteWidget * m_pNoteWidget;  ///< note widget to show documentation for
+    bool apply();
 };
 
 #endif
