@@ -12,30 +12,32 @@
 #define UMLOPERATIONDIALOG_H
 
 //kde includes
-#include <kdialog.h>
-
-//qt includes
-#include <QListWidgetItem>
+#include "singlepagedialogbase.h"
 
 class DocumentationWidget;
-class UMLOperation;
+class KComboBox;
 class ListPopupMenu;
+class QAbstractButton;
 class QGroupBox;
 class QListWidget;
+class QListWidgetItem;
 class QLabel;
 class QRadioButton;
 class QPushButton;
 class QCheckBox;
-class KComboBox;
+class QToolButton;
 class KLineEdit;
 class UMLDoc;
-class QToolButton;
+class UMLOperation;
+class UMLDatatypeWidget;
+class UMLStereotypeWidget;
+class VisibilityEnumWidget;
 
 /**
  * @author Paul Hensgen
  * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
  */
-class UMLOperationDialog : public KDialog
+class UMLOperationDialog : public SinglePageDialogBase
 {
     Q_OBJECT
 public:
@@ -50,35 +52,34 @@ protected:
     bool apply();
 
     void insertTypesSorted(const QString& type = QString());
-    void insertStereotypesSorted(const QString& type);
 
-    UMLOperation*  m_operation;  ///< The operation to represent.
-    UMLDoc*        m_doc;        ///< The UMLDocument where all objects live.
-    ListPopupMenu* m_menu;       ///< Menu used in parameter list box.
+    UMLOperation*     m_operation;  ///< The operation to represent.
+    UMLDoc*           m_doc;        ///< The UMLDocument where all objects live.
+    ListPopupMenu*    m_menu;       ///< Menu used in parameter list box.
 
     //GUI widgets
-    QGroupBox*    m_pParmsGB;
-    QGroupBox*    m_pGenGB;
-    QListWidget*  m_pParmsLW;
-    QGroupBox*    m_pScopeGB;
-    QRadioButton* m_pPublicRB;
-    QRadioButton* m_pPrivateRB;
-    QRadioButton* m_pProtectedRB;
-    QRadioButton* m_pImplementationRB;
-    QLabel*       m_pRtypeL;
-    QLabel*       m_pNameL;
-    QLabel*       m_pStereoTypeL;
-    KComboBox*    m_pRtypeCB;
-    KComboBox*    m_pStereoTypeCB;
-    KLineEdit*    m_pNameLE;
-    QCheckBox*    m_pAbstractCB;
-    QCheckBox*    m_pStaticCB;
-    QCheckBox*    m_pQueryCB;
-    QPushButton*  m_pDeleteButton;
-    QPushButton*  m_pPropertiesButton;
-    QToolButton*  m_pUpButton;
-    QToolButton*  m_pDownButton;
+    QGroupBox*            m_pParmsGB;
+    QGroupBox*            m_pGenGB;
+    QListWidget*          m_pParmsLW;
+    QGroupBox*            m_pScopeGB;
+    QRadioButton*         m_pPublicRB;
+    QRadioButton*         m_pPrivateRB;
+    QRadioButton*         m_pProtectedRB;
+    QRadioButton*         m_pImplementationRB;
+    QLabel*               m_pNameL;
+    UMLDatatypeWidget*    m_datatypeWidget;
+    UMLStereotypeWidget*  m_stereotypeWidget;
+    KLineEdit*            m_pNameLE;
+    QCheckBox*            m_pAbstractCB;
+    QCheckBox*            m_pStaticCB;
+    QCheckBox*            m_pQueryCB;
+    QCheckBox*            m_pOverrideCB;
+    QPushButton*          m_pDeleteButton;
+    QPushButton*          m_pPropertiesButton;
+    QToolButton*          m_pUpButton;
+    QToolButton*          m_pDownButton;
     DocumentationWidget*  m_docWidget;
+    VisibilityEnumWidget* m_visibilityEnumWidget;
 
 public slots:
     void slotParmRightButtonPressed(const QPoint &p);
@@ -89,14 +90,8 @@ public slots:
     void slotParameterProperties();
     void slotParameterUp();
     void slotParameterDown();
-
     void slotParamsBoxClicked(QListWidgetItem* parameterItem);
-
-    void slotApply();
-
-    void slotOk();
     void slotNameChanged(const QString &);
-
 };
 
 #endif
