@@ -89,6 +89,7 @@ ListPopupMenu::ListPopupMenu(QWidget *parent, MenuType type, WidgetBase *widget)
     m_TriggerObject.m_Widget = widget;
     m_TriggerObjectType = tot_Widget;
     setupMenu(type);
+    setActionChecked(mt_AutoResize, widget->autoResize());
     setupActionsData();
 }
 
@@ -159,6 +160,10 @@ ListPopupMenu::ListPopupMenu(QWidget *parent, UMLListViewItem::ListViewType type
         mt = mt_Class_Diagram;
         break;
 
+    case UMLListViewItem::lvt_Object_Diagram:
+        mt = mt_Object_Diagram;
+        break;
+
     case UMLListViewItem::lvt_Collaboration_Diagram:
         mt = mt_Collaboration_Diagram;
         break;
@@ -267,6 +272,14 @@ ListPopupMenu::ListPopupMenu(QWidget *parent, UMLListViewItem::ListViewType type
         mt = mt_EntityAttribute;
         break;
 
+    case UMLListViewItem::lvt_Instance:
+        mt = mt_Instance;
+        break;
+
+    case UMLListViewItem::lvt_InstanteAttribute:
+        mt = mt_InstanceAttribute;
+        break;
+
     case UMLListViewItem::lvt_UniqueConstraint:
         mt = mt_UniqueConstraint;
         break;
@@ -340,7 +353,7 @@ ListPopupMenu::ListPopupMenu(QWidget *parent, UMLListViewItem::ListViewType type
  * @param multi    True if multiple items are selected.
  * @param uniqueType The type of widget shared by all selected widgets
  */
-ListPopupMenu::ListPopupMenu(QWidget * parent, WidgetBase * object, bool multi, WidgetBase::WidgetType uniqueType)
+ListPopupMenu::ListPopupMenu(QWidget * parent, WidgetBase * widget, bool multi, WidgetBase::WidgetType uniqueType)
 #if QT_VERSION >= 0x050000
     : QMenu(parent),
 #else
@@ -348,28 +361,29 @@ ListPopupMenu::ListPopupMenu(QWidget * parent, WidgetBase * object, bool multi,
 #endif
     m_isListView(false)
 {
-    m_TriggerObject.m_Widget = object;
+    m_TriggerObject.m_Widget = widget;
     m_TriggerObjectType = tot_Widget;
 
-    if (!object)
+    if (!widget)
         return;
 
     if (multi) {
         insertMultiSelectionMenu(uniqueType);
     } else {
-        insertSingleSelectionMenu(object);
+        insertSingleSelectionMenu(widget);
     }
 
     bool bCutState = UMLApp::app()->isCutCopyState();
     setActionEnabled(mt_Cut, bCutState);
     setActionEnabled(mt_Copy, bCutState);
     bool pasteAvailable = false;
-    if (object->isNoteWidget() &&
+    if (widget->isNoteWidget() &&
             UMLApp::app()->listView()->startedCopy()) {
-        NoteWidget::s_pCurrentNote = object->asNoteWidget();
+        NoteWidget::s_pCurrentNote = widget->asNoteWidget();
         pasteAvailable = true;
     }
     setActionEnabled(mt_Paste, pasteAvailable);
+    setActionChecked(mt_AutoResize, widget->autoResize());
     setupActionsData();
 }
 
@@ -419,7 +433,20 @@ void ListPopupMenu::insertSingleSelectionMenu(WidgetBase* object)
        }
     case WidgetBase::wt_Class:
     case WidgetBase::wt_Interface:
-        makeClassifierPopup(static_cast<ClassifierWidget*>(object));
+        {
+            ClassifierWidget* classifier = object->asClassifierWidget();
+            if (classifier)
+                makeClassifierPopup(classifier);
+        }
+        break;
+
+    case WidgetBase::wt_Instance:
+        insert(mt_InstanceAttribute);
+        insert(mt_Rename_Object);
+        insert(mt_Rename, i18n("Rename Class..."));
+        insertStdItems(true, type);
+        insert(mt_Change_Font);
+        insert(mt_Properties);
         break;
 
     case WidgetBase::wt_Enum:
@@ -466,28 +493,27 @@ void ListPopupMenu::insertSingleSelectionMenu(WidgetBase* object)
         break;
 
     case WidgetBase::wt_Object:
-        {
-            //Used for sequence diagram and collaboration diagram widgets
-            insertSubMenuColor(object->useFillColor());
-            if (object->umlScene() &&
-                object->umlScene()->type() == Uml::DiagramType::Sequence) {
-                addSeparator();
-                MenuType tabUp = mt_Up;
-                insert(mt_Up, Icon_Utils::SmallIcon(Icon_Utils::it_Arrow_Up), i18n("Move Up"));
-                insert(mt_Down, Icon_Utils::SmallIcon(Icon_Utils::it_Arrow_Down), i18n("Move Down"));
-                if (!(static_cast<ObjectWidget*>(object))->canTabUp()) {
-                    setActionEnabled(tabUp, false);
-                }
+        //Used for sequence diagram and collaboration diagram widgets
+        insertSubMenuColor(object->useFillColor());
+        if (object->umlScene() &&
+            object->umlScene()->type() == Uml::DiagramType::Sequence) {
+            addSeparator();
+            MenuType tabUp = mt_Up;
+            insert(mt_Up, Icon_Utils::SmallIcon(Icon_Utils::it_Arrow_Up), i18n("Move Up"));
+            insert(mt_Down, Icon_Utils::SmallIcon(Icon_Utils::it_Arrow_Down), i18n("Move Down"));
+            if (!(static_cast<ObjectWidget*>(object))->canTabUp()) {
+                setActionEnabled(tabUp, false);
             }
-            insertStdItems(true, type);
-            insert(mt_Rename, i18n("Rename Class..."));
-            insert(mt_Rename_Object, i18n("Rename Object..."));
-            insert(mt_Change_Font);
-            insert(mt_Properties);
         }
+        insertStdItems(true, type);
+        insert(mt_Rename_Object);
+        insert(mt_Rename, i18n("Rename Class..."));
+        insert(mt_Change_Font);
+        insert(mt_Properties);
         break;
 
     case WidgetBase::wt_Message:
+        insertSubMenuColor(object->useFillColor());
         insertStdItems(false, type);
         //insert(mt_Change_Font);
         //insert(mt_Operation, Icon_Utils::SmallIcon(Icon_Utils::it_Operation_New), i18n("New Operation..."));
@@ -712,7 +738,7 @@ void ListPopupMenu::insertMultiSelectionMenu(WidgetBase::WidgetType uniqueType)
     addSeparator();
     insert(mt_Clone);
     insert(mt_Delete);
-    insert(mt_Resize, i18n("Resize"));
+    insert(mt_Resize);
 
     addSeparator();
     insert(mt_Change_Font_Selection, Icon_Utils::SmallIcon(Icon_Utils::it_Change_Font), i18n("Change Font..."));
@@ -733,6 +759,12 @@ void ListPopupMenu::insert(MenuType m)
     case mt_Rename:
         m_actions[m] = addAction(Icon_Utils::SmallIcon(Icon_Utils::it_Rename), i18n("Rename..."));
         break;
+    case mt_Rename_Object:
+        insert(m, i18n("Rename Object..."));
+        break;
+    case mt_Resize:
+        insert(m, i18n("Resize"));
+        break;
     case mt_Show:
         m_actions[m] = addAction(Icon_Utils::SmallIcon(Icon_Utils::it_Show), i18n("Show"));
         break;
@@ -785,6 +817,7 @@ void ListPopupMenu::insert(MenuType m)
         m_actions[m] = addAction(Icon_Utils::SmallIcon(Icon_Utils::it_Operation_Public_New), i18n("New Operation..."));
         break;
     case mt_New_Attribute:
+    case mt_New_InstanceAttribute:
         m_actions[m] = addAction(Icon_Utils::SmallIcon(Icon_Utils::it_Attribute_New), i18n("New Attribute..."));
         break;
     case mt_New_Template:
@@ -799,6 +832,9 @@ void ListPopupMenu::insert(MenuType m)
     case mt_Export_Image:
         m_actions[m] = addAction(Icon_Utils::SmallIcon(Icon_Utils::it_Export_Picture), i18n("Export as Picture..."));
         break;
+    case mt_InstanceAttribute:
+        m_actions[m] = addAction(Icon_Utils::SmallIcon(Icon_Utils::it_Attribute_New), i18n("New Attribute..."));
+        break;
     default:
         uWarning() << "called on unimplemented MenuType " << toString(m);
         break;
@@ -977,7 +1013,10 @@ void ListPopupMenu::insertStdItems(bool insertLeadingSeparator /* = true */,
         insert(mt_Clone);
     insert(mt_Delete);
     if (!m_isListView)
-        insert(mt_Resize, i18n("Resize"));
+    {
+        insert(mt_Resize);
+        insert(mt_AutoResize, i18n("Auto resize"), CHECKABLE);
+    }
 }
 
 /**
@@ -986,8 +1025,10 @@ void ListPopupMenu::insertStdItems(bool insertLeadingSeparator /* = true */,
  *
  * @param folderAndDiagrams Set this true if folders and diagram
  *                          types shall be included as choices.
+ * @param packages          Set this true if packages
+ *                          shall be included as choices.
  */
-void ListPopupMenu::insertContainerItems(bool folderAndDiagrams)
+void ListPopupMenu::insertContainerItems(bool folderAndDiagrams, bool packages)
 {
 #if QT_VERSION >= 0x050000
     QMenu* menu = new QMenu(i18nc("new container menu", "New"), this);
@@ -995,13 +1036,34 @@ void ListPopupMenu::insertContainerItems(bool folderAndDiagrams)
     KMenu* menu = new KMenu(i18nc("new container menu", "New"), this);
 #endif
     menu->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_New));
+    insertContainerItems(menu, folderAndDiagrams, packages);
+    addMenu(menu);
+}
+
+/**
+ * Shortcut for inserting standard model items (Class, Interface,
+ * Datatype, Enum, Package) as well as diagram choices.
+ *
+ * @param menu              Menu to add the menu entries
+ * @param folderAndDiagrams Set this true if folders and diagram
+ *                          types shall be included as choices.
+ * @param packages          Set this true if packages
+ *                          shall be included as choices.
+ */
+#if QT_VERSION >= 0x050000
+void ListPopupMenu::insertContainerItems(QMenu* menu, bool folderAndDiagrams, bool packages)
+#else
+void ListPopupMenu::insertContainerItems(KMenu* menu, bool folderAndDiagrams, bool packages)
+#endif
+{
     if (folderAndDiagrams)
         insert(mt_Logical_Folder, menu, Icon_Utils::BarIcon(Icon_Utils::it_Folder), i18n("Folder"));
     insert(mt_Class, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Class), i18nc("new class menu item", "Class"));
     insert(mt_Interface, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Interface), i18n("Interface"));
     insert(mt_Datatype, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Datatype), i18n("Datatype"));
     insert(mt_Enum, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Enum), i18n("Enum"));
-    insert(mt_Package, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Package), i18n("Package"));
+    if (packages)
+        insert(mt_Package, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Package), i18n("Package"));
     if (folderAndDiagrams) {
         QAction *action = UMLApp::app()->actionCollection()->action(QLatin1String("new_class_diagram"));
         insert(mt_Class_Diagram, menu, action->icon(), action->text());
@@ -1014,7 +1076,6 @@ void ListPopupMenu::insertContainerItems(bool folderAndDiagrams)
         action = UMLApp::app()->actionCollection()->action(QLatin1String("new_activity_diagram"));
         insert(mt_Activity_Diagram, menu, action->icon(), action->text());
     }
-    addMenu(menu);
 }
 
 /**
@@ -1050,6 +1111,7 @@ void ListPopupMenu::insertAssociationItem(MenuType mt)
     insert(mt_Delete);
 
     switch(mt) {
+    case mt_AttributeAssociation:
     case mt_FullAssociation:
         insert(mt_Rename_Name, i18n("Change Association Name..."));
         insert(mt_Rename_RoleAName, i18n("Change Role A Name..."));
@@ -1317,6 +1379,10 @@ void ListPopupMenu::makeClassifierPopup(ClassifierWidget *c)
         insert(mt_Attribute, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Public_Attribute), i18n("Attribute..."));
     insert(mt_Operation, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Public_Method), i18n("Operation..."));
     insert(mt_Template, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Template_New), i18n("Template..."));
+    insert(mt_Class, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Class), i18nc("new class menu item", "Class..."));
+    insert(mt_Interface, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Interface), i18n("Interface..."));
+    insert(mt_Datatype, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Datatype), i18n("Datatype..."));
+    insert(mt_Enum, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Enum), i18n("Enum..."));
     addMenu(menu);
 
     makeClassifierShowPopup(c);
@@ -1336,7 +1402,7 @@ void ListPopupMenu::makeClassifierPopup(ClassifierWidget *c)
         insert(mt_Refactoring, Icon_Utils::SmallIcon(Icon_Utils::it_Refactor), i18n("Refactor"));
         insert(mt_ViewCode, Icon_Utils::SmallIcon(Icon_Utils::it_View_Code), i18n("View Code"));
         UMLClassifier *umlc = c->classifier();
-        if (umlc->isAbstract() && umlc->attributes() == 0)
+        if (umlc->isAbstract() && umlc->getAttributeList().size() == 0)
             insert(mt_ChangeToInterface, i18n("Change into Interface"));
     }
     insert(mt_Properties);
@@ -1418,12 +1484,21 @@ UMLObject::ObjectType ListPopupMenu::convert_MT_OT(MenuType mt)
     case mt_Class:
         type = UMLObject::ot_Class;
         break;
+    case mt_Datatype:
+        type = UMLObject::ot_Datatype;
+        break;
     case mt_Attribute:
         type = UMLObject::ot_Attribute;
         break;
+    case mt_Interface:
+        type = UMLObject::ot_Interface;
+        break;
     case mt_Template:
         type = UMLObject::ot_Template;
         break;
+    case mt_Enum:
+        type = UMLObject::ot_Enum;
+        break;
     case mt_EnumLiteral:
         type = UMLObject::ot_EnumLiteral;
         break;
@@ -1436,6 +1511,9 @@ UMLObject::ObjectType ListPopupMenu::convert_MT_OT(MenuType mt)
     case mt_Category:
         type = UMLObject::ot_Category;
         break;
+    case mt_InstanceAttribute:
+        type = UMLObject::ot_InstanceAttribute;
+        break;
     default:
         break;
     }
@@ -1534,6 +1612,7 @@ void ListPopupMenu::insertSubMenuNew(MenuType type)
             insert(mt_FloatText, menu);
             break;
         case mt_On_Class_Diagram:
+            insert(mt_Import_from_File, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Import_File), i18n("from file..."));
             insert(mt_Class, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Class), i18nc("new class menu item", "Class..."));
             insert(mt_Interface, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Interface), i18n("Interface..."));
             insert(mt_Datatype, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Datatype), i18n("Datatype..."));
@@ -1541,6 +1620,9 @@ void ListPopupMenu::insertSubMenuNew(MenuType type)
             insert(mt_Package, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Package), i18n("Package..."));
             insert(mt_FloatText, menu);
             break;
+         case mt_On_Object_Diagram:
+            insert(mt_Instance, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Instance), i18nc("new instance menu item", "Instance..."));
+        break;
         case mt_On_State_Diagram:
             insert(mt_Initial_State, menu, Icon_Utils::SmallIcon(Icon_Utils::it_InitialState), i18n("Initial State"));
             insert(mt_End_State, menu, Icon_Utils::SmallIcon(Icon_Utils::it_EndState), i18n("End State"));
@@ -1575,7 +1657,7 @@ void ListPopupMenu::insertSubMenuNew(MenuType type)
             insert(mt_Category, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Category), i18n("Category..."));
             break;
         case mt_On_Sequence_Diagram:
-            insert(mt_Import_from_File, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Import_File), i18n("Import stack trace..."));
+            insert(mt_Import_from_File, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Import_File), i18n("from file..."));
             insert(mt_Object, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Object), i18n("Object..."));
             insert(mt_FloatText, menu);
             break;
@@ -1587,10 +1669,12 @@ void ListPopupMenu::insertSubMenuNew(MenuType type)
             insert(mt_Attribute, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Public_Attribute), i18n("Attribute"));
             insert(mt_Operation, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Public_Method), i18n("Operation"));
             insert(mt_Template, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Template_Class), i18n("Template"));
+            insertContainerItems(menu, false, false);
             break;
         case mt_Interface:
             insert(mt_Operation, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Public_Method), i18n("Operation"));
             insert(mt_Template, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Template_Interface), i18n("Template"));
+            insertContainerItems(menu, false, false);
             break;
         case mt_Entity:
             insert(mt_EntityAttribute, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Entity_Attribute), i18n("Entity Attribute..."));
@@ -1726,6 +1810,7 @@ void ListPopupMenu::setupMenu(MenuType type)
     case mt_UseCase_Diagram:
     case mt_Sequence_Diagram:
     case mt_Class_Diagram:
+    case mt_Object_Diagram:
     case mt_Collaboration_Diagram:
     case mt_State_Diagram:
     case mt_Activity_Diagram:
@@ -1739,81 +1824,19 @@ void ListPopupMenu::setupMenu(MenuType type)
         break;
 
     case mt_On_UseCase_Diagram:
-        insertSubMenuNew(type);
-        addSeparator();
-        if (m_TriggerObjectType != tot_View) {
-            uError() << "Invalid Trigger Object Type Set for Use Case Diagram " << m_TriggerObjectType;
-            return;
-        }
-        setupDiagramMenu(m_TriggerObject.m_View);
-        break;
-
     case mt_On_Class_Diagram:
-        insertSubMenuNew(type);
-        addSeparator();
-        if (m_TriggerObjectType != tot_View) {
-            uError() << "Invalid Trigger Object Type Set for Use Case Diagram " << m_TriggerObjectType;
-            return;
-        }
-        setupDiagramMenu(m_TriggerObject.m_View);
-        break;
-
+    case mt_On_Object_Diagram:
     case mt_On_State_Diagram:
-        insertSubMenuNew(type);
-        addSeparator();
-        if (m_TriggerObjectType != tot_View) {
-            uError() << "Invalid Trigger Object Type Set for Use Case Diagram " << m_TriggerObjectType;
-            return;
-        }
-        setupDiagramMenu(m_TriggerObject.m_View);
-        break;
-
     case mt_On_Activity_Diagram:
-        insertSubMenuNew(type);
-        addSeparator();
-        if (m_TriggerObjectType != tot_View) {
-            uError() << "Invalid Trigger Object Type Set for Use Case Diagram " << m_TriggerObjectType;
-            return;
-        }
-        setupDiagramMenu(m_TriggerObject.m_View);
-        break;
-
     case mt_On_Component_Diagram:
-        insertSubMenuNew(type);
-        addSeparator();
-        if (m_TriggerObjectType != tot_View) {
-            uError() << "Invalid Trigger Object Type Set for Use Case Diagram " << m_TriggerObjectType;
-            return;
-        }
-        setupDiagramMenu(m_TriggerObject.m_View);
-        break;
-
     case mt_On_Deployment_Diagram:
-        insertSubMenuNew(type);
-        addSeparator();
-        if (m_TriggerObjectType != tot_View) {
-            uError() << "Invalid Trigger Object Type Set for Use Case Diagram " << m_TriggerObjectType;
-            return;
-        }
-        setupDiagramMenu(m_TriggerObject.m_View);
-        break;
-
     case mt_On_EntityRelationship_Diagram:
-        insertSubMenuNew(type);
-        addSeparator();
-        if (m_TriggerObjectType != tot_View) {
-            uError() << "Invalid Trigger Object Type Set for Use Case Diagram " << m_TriggerObjectType;
-            return;
-        }
-        setupDiagramMenu(m_TriggerObject.m_View);
-        break;
-
     case mt_On_Sequence_Diagram:
     case mt_On_Collaboration_Diagram:
         insertSubMenuNew(type);
         addSeparator();
         if (m_TriggerObjectType != tot_View) {
-            uError() << "Invalid Trigger Object Type Set for Use Case Diagram " << m_TriggerObjectType;
+            uError() << "Invalid Trigger Object Type" << m_TriggerObjectType << "for diagram type" << type;
             return;
         }
         setupDiagramMenu(m_TriggerObject.m_View);
@@ -1896,6 +1919,7 @@ void ListPopupMenu::setupMenu(MenuType type)
     case mt_UseCase:
     case mt_Attribute:
     case mt_EntityAttribute:
+    case mt_InstanceAttribute:
     case mt_Operation:
     case mt_Template:
         insertStdItems(false);
@@ -1940,6 +1964,10 @@ void ListPopupMenu::setupMenu(MenuType type)
         insert(mt_New_Attribute);
         break;
 
+    case mt_New_InstanceAttribute:
+        insert(mt_New_InstanceAttribute);
+        break;
+
     case mt_New_Template:
         insert(mt_New_Template);
         break;
@@ -1997,6 +2025,12 @@ void ListPopupMenu::setupMenu(MenuType type)
         insert(mt_Properties);
         break;
 
+    case mt_InstanceAttribute_Selected:
+        insert(mt_New_InstanceAttribute);
+        insert(mt_Delete);
+        insert(mt_Properties);
+        break;
+
     case mt_Template_Selected:
         insert(mt_New_Attribute, Icon_Utils::SmallIcon(Icon_Utils::it_Template_New), i18n("New Template..."));
         insert(mt_Delete);
