@@ -195,7 +195,7 @@ public:
     QString activeLanguageScopeSeparator();
 
     KConfig* config();
-    void importFiles(QStringList* fileList);
+    void importFiles(QStringList& fileList, const QString &rootPath = QString());
 
 protected:
     virtual void keyPressEvent(QKeyEvent* e);
@@ -249,6 +249,7 @@ public slots:
     void slotEditPaste();
     void slotStatusMsg(const QString &text);
     void slotClassDiagram();
+    void slotObjectDiagram();
     void slotSequenceDiagram();
     void slotCollaborationDiagram();
     void slotUseCaseDiagram();
@@ -306,7 +307,7 @@ public slots:
     void slotZoomOut();
     void slotZoomIn();
 
-    void slotBirdViewChanged(const QPoint& delta);
+    void slotBirdViewChanged(const QPointF& newCenter);
 
     void setupZoomMenu();
 
@@ -391,7 +392,7 @@ private:
      * It is kept empty so you can create your view according to your
      * application's needs by changing the view class.
      */
-    UMLView* m_view;
+    QPointer<UMLView> m_view;
 
     /**
      * Doc represents your actual document and is created only once.
@@ -519,6 +520,7 @@ private:
 signals:
     void sigCutSuccessful();
 
+    friend class UMLAppPrivate;
     friend class UMLView;
 };
 
