@@ -167,17 +167,17 @@ public:
 
     static bool tagEq (const QString& tag, const QString& pattern);
 
-    virtual void saveToXMI(QIODevice& file);
+    virtual void saveToXMI1(QIODevice& file);
 
     short encoding(QIODevice & file);
 
-    virtual bool loadFromXMI(QIODevice& file, short encode = ENC_UNKNOWN);
+    virtual bool loadFromXMI1(QIODevice& file, short encode = ENC_UNKNOWN);
 
-    bool validateXMIHeader(QDomNode& headerNode);
+    bool validateXMI1Header(QDomNode& headerNode);
 
-    bool loadUMLObjectsFromXMI(QDomElement & element);
-    void loadExtensionsFromXMI(QDomNode & node);
-    bool loadDiagramsFromXMI(QDomNode & node);
+    bool loadUMLObjectsFromXMI1(QDomElement & element);
+    void loadExtensionsFromXMI1(QDomNode & node);
+    bool loadDiagramsFromXMI1(QDomNode & node);
 
     void signalDiagramRenamed(UMLView * view);
     void signalUMLObjectCreated(UMLObject * o);
@@ -222,6 +222,9 @@ public:
     bool loading() const;
     void setLoading(bool state = true);
 
+    bool importing() const;
+    void setImporting(bool state = true);
+
     bool closing() const;
 
     void addDefaultDatatypes();
@@ -239,7 +242,7 @@ public:
     void writeToStatusBar(const QString &text);
 
     void resolveTypes();
-    bool loadDiagrams();
+    bool loadDiagrams1();
     void addDiagramToLoad(UMLFolder *folder, QDomNode node);
 
     DiagramsModel *diagramsModel();
@@ -289,6 +292,11 @@ private:
      */
     bool m_bLoading;
 
+    /**
+     * true if the we're importing
+     */
+    bool m_importing;
+
     /**
      * Documentation for the project.
      */
