@@ -138,7 +138,7 @@ void EnumWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *option
     painter->drawLine(0, y, w, y);
 
     QFontMetrics fontMetrics(font);
-    UMLClassifier *classifier = (UMLClassifier*)m_umlObject;
+    UMLClassifier *classifier = m_umlObject->asUMLClassifier();
     UMLClassifierListItem* enumLiteral = 0;
     UMLClassifierListItemList list = classifier->getFilteredList(UMLObject::ot_EnumLiteral);
     foreach (enumLiteral, list) {
@@ -155,9 +155,9 @@ void EnumWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *option
 /**
  * Loads from an "enumwidget" XMI element.
  */
-bool EnumWidget::loadFromXMI(QDomElement & qElement)
+bool EnumWidget::loadFromXMI1(QDomElement & qElement)
 {
-    if (!UMLWidget::loadFromXMI(qElement)) {
+    if (!UMLWidget::loadFromXMI1(qElement)) {
         return false;
     }
     QString showpackage = qElement.attribute(QLatin1String("showpackage"), QLatin1String("0"));
@@ -170,10 +170,10 @@ bool EnumWidget::loadFromXMI(QDomElement & qElement)
 /**
  * Saves to the "enumwidget" XMI element.
  */
-void EnumWidget::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
+void EnumWidget::saveToXMI1(QDomDocument& qDoc, QDomElement& qElement)
 {
     QDomElement conceptElement = qDoc.createElement(QLatin1String("enumwidget"));
-    UMLWidget::saveToXMI(qDoc, conceptElement);
+    UMLWidget::saveToXMI1(qDoc, conceptElement);
 
     conceptElement.setAttribute(QLatin1String("showpackage"), m_showPackage);
     qElement.appendChild(conceptElement);
@@ -189,7 +189,7 @@ void EnumWidget::slotMenuSelection(QAction* action)
 {
     ListPopupMenu::MenuType sel = ListPopupMenu::typeFromAction(action);
     if (sel == ListPopupMenu::mt_EnumLiteral) {
-        if (Object_Factory::createChildObject(static_cast<UMLClassifier*>(m_umlObject),
+        if (Object_Factory::createChildObject(m_umlObject->asUMLClassifier(),
                                               UMLObject::ot_EnumLiteral))  {
             /* I don't know why it works without these calls:
             updateComponentSize();
@@ -223,7 +223,7 @@ QSizeF EnumWidget::minimumSize() const
     int lines = 1;//always have one line - for name
     lines++; //for the stereotype
 
-    const int numberOfEnumLiterals = ((UMLEnum*)m_umlObject)->enumLiterals();
+    const int numberOfEnumLiterals = m_umlObject->asUMLEnum()->enumLiterals();
 
     height = width = 0;
     //set the height of the enum
@@ -247,7 +247,7 @@ QSizeF EnumWidget::minimumSize() const
 
     width = w > width?w:width;
 
-    UMLClassifier *classifier = (UMLClassifier*)m_umlObject;
+    UMLClassifier *classifier = m_umlObject->asUMLClassifier();
     UMLClassifierListItemList list = classifier->getFilteredList(UMLObject::ot_EnumLiteral);
     UMLClassifierListItem* listItem = 0;
     foreach (listItem, list) {
