@@ -130,8 +130,8 @@ void MessageWidget::init()
     m_yclicked = -1;
     m_ignoreSnapToGrid = true;
     m_ignoreSnapComponentSizeToGrid = true;
-    m_pOw[Uml::RoleType::A] = m_pOw[Uml::RoleType::B] = NULL;
-    m_pFText = NULL;
+    m_pOw[Uml::RoleType::A] = m_pOw[Uml::RoleType::B] = 0;
+    m_pFText = 0;
 }
 
 /**
@@ -376,6 +376,10 @@ void MessageWidget::paintSynchronous(QPainter *painter, const QStyleOptionGraphi
     const int boxWidth = 17;
     const int wr = w < boxWidth ? w : boxWidth;
     const int arrowWidth = 4;
+    if (UMLWidget::useFillColor())
+        painter->setBrush(UMLWidget::fillColor());
+    else
+        painter->setBrush(m_scene->backgroundColor());
 
     if(isSelf()) {
         painter->fillRect(offsetX, offsetY, wr, h,  QBrush(Qt::white));              //box
@@ -605,17 +609,17 @@ UMLWidget* MessageWidget::onWidget(const QPointF& p)
     // Synchronous message:
     // Consists of top arrow (call) and bottom arrow (return.)
     if (p.x() < x() || p.x() > x() + width())
-        return NULL;
+        return 0;
     const int tolerance = 5;  // pixels
     const int pY = p.y();
     const int topArrowY = y() + 3;
     const int bottomArrowY = y() + height() - 3;
     if (pY < topArrowY - tolerance || pY > bottomArrowY + tolerance)
-        return NULL;
+        return 0;
     if (height() <= 2 * tolerance)
         return this;
     if (pY > topArrowY + tolerance && pY < bottomArrowY - tolerance)
-        return NULL;
+        return 0;
     return this;
 }
 
@@ -624,7 +628,7 @@ UMLWidget* MessageWidget::onWidget(const QPointF& p)
  */
 void MessageWidget::setTextPosition()
 {
-    if (m_pFText == NULL) {
+    if (m_pFText == 0) {
         DEBUG(DBG_SRC) << "m_pFText is NULL";
         return;
     }
@@ -649,7 +653,7 @@ int MessageWidget::constrainX(int textX, int textWidth, Uml::TextRole::Enum tr)
     if (textX < minTextX || tr == Uml::TextRole::Seq_Message_Self) {
         result = minTextX;
     } else {
-        ObjectWidget *objectAtRight = NULL;
+        ObjectWidget *objectAtRight = 0;
         if (m_pOw[Uml::RoleType::B]->x() > m_pOw[Uml::RoleType::A]->x())
             objectAtRight = m_pOw[Uml::RoleType::B];
         else
@@ -784,27 +788,27 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
 {
     m_scene->resetPastePoint();
     // UMLWidget::activate(Log);   CHECK: I don't think we need this ?
-    if (m_pOw[Uml::RoleType::A] == NULL) {
+    if (m_pOw[Uml::RoleType::A] == 0) {
         UMLWidget *pWA = m_scene->findWidget(m_widgetAId);
-        if (pWA == NULL) {
+        if (pWA == 0) {
             DEBUG(DBG_SRC) << "role A object " << Uml::ID::toString(m_widgetAId) << " not found";
             return false;
         }
-        m_pOw[Uml::RoleType::A] = dynamic_cast<ObjectWidget*>(pWA);
-        if (m_pOw[Uml::RoleType::A] == NULL) {
+        m_pOw[Uml::RoleType::A] = pWA->asObjectWidget();
+        if (m_pOw[Uml::RoleType::A] == 0) {
             DEBUG(DBG_SRC) << "role A widget " << Uml::ID::toString(m_widgetAId)
                 << " is not an ObjectWidget";
             return false;
         }
     }
-    if (m_pOw[Uml::RoleType::B] == NULL) {
+    if (m_pOw[Uml::RoleType::B] == 0) {
         UMLWidget *pWB = m_scene->findWidget(m_widgetBId);
-        if (pWB == NULL) {
+        if (pWB == 0) {
             DEBUG(DBG_SRC) << "role B object " << Uml::ID::toString(m_widgetBId) << " not found";
             return false;
         }
-        m_pOw[Uml::RoleType::B] = dynamic_cast<ObjectWidget*>(pWB);
-        if (m_pOw[Uml::RoleType::B] == NULL) {
+        m_pOw[Uml::RoleType::B] = pWB->asObjectWidget();
+        if (m_pOw[Uml::RoleType::B] == 0) {
             DEBUG(DBG_SRC) << "role B widget " << Uml::ID::toString(m_widgetBId)
                 << " is not an ObjectWidget";
             return false;
@@ -812,11 +816,11 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
     }
     updateResizability();
 
-    UMLClassifier *c = dynamic_cast<UMLClassifier*>(m_pOw[Uml::RoleType::B]->umlObject());
-    UMLOperation *op = NULL;
+    UMLClassifier *c = m_pOw[Uml::RoleType::B]->umlObject()->asUMLClassifier();
+    UMLOperation *op = 0;
     if (c && !m_CustomOp.isEmpty()) {
         Uml::ID::Type opId = Uml::ID::fromString(m_CustomOp);
-        op = dynamic_cast<UMLOperation*>(c->findChildObjectById(opId, true));
+        op = c->findChildObjectById(opId, true)->asUMLOperation();
         if (op) {
             // If the UMLOperation is set, m_CustomOp isn't used anyway.
             // Just setting it empty for the sake of sanity.
@@ -876,7 +880,7 @@ void MessageWidget::resolveObjectWidget(IDChangeLog* log) {
  */
 void MessageWidget::setMessageText(FloatingTextWidget *ft)
 {
-    if (ft == NULL)
+    if (ft == 0)
         return;
     ft->setSequenceNumber(m_SequenceNumber);
     ft->setText(operationText(m_scene));
@@ -924,9 +928,9 @@ void MessageWidget::lwSetFont (QFont font)
 UMLClassifier *MessageWidget::operationOwner()
 {
     UMLObject *pObject = m_pOw[Uml::RoleType::B]->umlObject();
-    if (pObject == NULL)
-        return NULL;
-    UMLClassifier *c = dynamic_cast<UMLClassifier*>(pObject);
+    if (pObject == 0)
+        return 0;
+    UMLClassifier *c = pObject->asUMLClassifier();
     return c;
 }
 
@@ -936,7 +940,7 @@ UMLClassifier *MessageWidget::operationOwner()
  */
 UMLOperation *MessageWidget::operation()
 {
-    return static_cast<UMLOperation*>(m_umlObject);
+    return m_umlObject->asUMLOperation();
 }
 
 /**
@@ -980,7 +984,7 @@ void MessageWidget::setCustomOpText(const QString &opText)
 QString MessageWidget::lwOperationText()
 {
     UMLOperation *pOperation = operation();
-    if (pOperation != NULL) {
+    if (pOperation != 0) {
         return pOperation->toString(Uml::SignatureType::SigNoVis);
     } else {
         return customOpText();
@@ -994,7 +998,7 @@ QString MessageWidget::lwOperationText()
 UMLClassifier *MessageWidget::lwClassifier()
 {
     UMLObject *o = m_pOw[Uml::RoleType::B]->umlObject();
-    UMLClassifier *c = dynamic_cast<UMLClassifier*>(o);
+    UMLClassifier *c = o->asUMLClassifier();
     return c;
 }
 
@@ -1035,7 +1039,6 @@ void MessageWidget::calculateDimensionsSynchronous()
     int x2 = m_pOw[Uml::RoleType::B]->centerX();
 
     int widgetWidth = 0;
-    int widgetHeight = 0;
     if(isSelf()) {
         widgetWidth = 50;
         x = x1 - 2;
@@ -1047,8 +1050,10 @@ void MessageWidget::calculateDimensionsSynchronous()
         widgetWidth = x1 - x2 + 8;
     }
 
-    if (height() < 20) {
-        widgetHeight = 20;
+    QSizeF minSize = minimumSize();
+    int widgetHeight = 0;
+    if (height() < minSize.height()) {
+        widgetHeight = minSize.height();
     } else {
         widgetHeight = height();
     }
@@ -1068,15 +1073,9 @@ void MessageWidget::calculateDimensionsAsynchronous()
     int x2 = m_pOw[Uml::RoleType::B]->centerX();
 
     int widgetWidth = 0;
-    int widgetHeight = 8;
     if(isSelf()) {
         widgetWidth = 50;
         x = x1;
-        if(height() < 20) {
-            widgetHeight = 20;
-        } else {
-            widgetHeight = height();
-        }
     } else if(x1 < x2) {
         x = x1;
         widgetWidth = x2 - x1;
@@ -1086,6 +1085,15 @@ void MessageWidget::calculateDimensionsAsynchronous()
     }
     x += 1;
     widgetWidth -= 2;
+
+    QSizeF minSize = minimumSize();
+    int widgetHeight = 0;
+    if (height() < minSize.height()) {
+        widgetHeight = minSize.height();
+    } else {
+        widgetHeight = height();
+    }
+
     setX(x);
     setSize(widgetWidth, widgetHeight);
 }
@@ -1105,7 +1113,6 @@ void MessageWidget::calculateDimensionsCreation()
         x2 += w2;
 
     int widgetWidth = 0;
-    int widgetHeight = 8;
     if (x1 < x2) {
         x = x1;
         widgetWidth = x2 - x1;
@@ -1115,6 +1122,9 @@ void MessageWidget::calculateDimensionsCreation()
     }
     x += 1;
     widgetWidth -= 2;
+
+    int widgetHeight = minimumSize().height();
+
     setPos(x, m_pOw[Uml::RoleType::B]->y() + m_pOw[Uml::RoleType::B]->height() / 2);
     setSize(widgetWidth, widgetHeight);
 }
@@ -1130,7 +1140,6 @@ void MessageWidget::calculateDimensionsLost()
     int x2 = m_xclicked;
 
     int widgetWidth = 0;
-    int widgetHeight = 10;
     if(x1 < x2) {
         x = x1;
         widgetWidth = x2 - x1 + circleWidth/2;
@@ -1138,6 +1147,9 @@ void MessageWidget::calculateDimensionsLost()
         x = x2 - circleWidth/2;
         widgetWidth = x1 - x2 + circleWidth/2;
     }
+
+    int widgetHeight = minimumSize().height();
+
     setX(x);
     setSize(widgetWidth, widgetHeight);
 }
@@ -1153,7 +1165,6 @@ void MessageWidget::calculateDimensionsFound()
     int x2 = m_xclicked;
 
     int widgetWidth = 0;
-    int widgetHeight = 10;
     if(x1 < x2) {
         x = x1;
         widgetWidth = x2 - x1 + circleWidth/2;
@@ -1162,6 +1173,8 @@ void MessageWidget::calculateDimensionsFound()
         widgetWidth = x1 - x2 + circleWidth/2;
     }
 
+    int widgetHeight = minimumSize().height();
+
     setX(x);
     setSize(widgetWidth, widgetHeight);
 }
@@ -1183,7 +1196,7 @@ void MessageWidget::cleanup()
     UMLWidget::cleanup();
     if (m_pFText) {
         m_scene->removeWidgetCmd(m_pFText);
-        m_pFText = NULL;
+        m_pFText = 0;
     }
 }
 
@@ -1312,7 +1325,7 @@ void MessageWidget::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
 {
     Q_UNUSED(event)
     DEBUG(DBG_SRC) << "NOT IMPLEMENTED YET!";
-    if (m_pFText != NULL) {
+    if (m_pFText != 0) {
         DEBUG(DBG_SRC) << "NOT IMPLEMENTED YET - on floating text widget!";
 //        QAction* action = m_pMenu->getAction(ListPopupMenu::mt_Select_Operation);
 //        m_pFText->slotMenuSelection(action);
@@ -1322,11 +1335,11 @@ void MessageWidget::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
 /**
  * Saves to the "messagewidget" XMI element.
  */
-void MessageWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
+void MessageWidget::saveToXMI1(QDomDocument & qDoc, QDomElement & qElement)
 {
     QDomElement messageElement = qDoc.createElement(QLatin1String("messagewidget"));
-    UMLWidget::saveToXMI(qDoc, messageElement);
-    LinkWidget::saveToXMI(qDoc, messageElement);
+    UMLWidget::saveToXMI1(qDoc, messageElement);
+    LinkWidget::saveToXMI1(qDoc, messageElement);
     if (m_pOw[Uml::RoleType::A])
         messageElement.setAttribute(QLatin1String("widgetaid"), Uml::ID::toString(m_pOw[Uml::RoleType::A]->localID()));
     if (m_pOw[Uml::RoleType::B])
@@ -1345,7 +1358,7 @@ void MessageWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
     // save the corresponding message text
     if (m_pFText && !m_pFText->text().isEmpty()) {
         messageElement.setAttribute(QLatin1String("textid"), Uml::ID::toString(m_pFText->id()));
-        m_pFText->saveToXMI(qDoc, messageElement);
+        m_pFText->saveToXMI1(qDoc, messageElement);
     }
 
     qElement.appendChild(messageElement);
@@ -1354,12 +1367,12 @@ void MessageWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
 /**
  * Loads from the "messagewidget" XMI element.
  */
-bool MessageWidget::loadFromXMI(QDomElement& qElement)
+bool MessageWidget::loadFromXMI1(QDomElement& qElement)
 {
-    if (!UMLWidget::loadFromXMI(qElement)) {
+    if (!UMLWidget::loadFromXMI1(qElement)) {
         return false;
     }
-    if (!LinkWidget::loadFromXMI(qElement)) {
+    if (!LinkWidget::loadFromXMI1(qElement)) {
         return false;
     }
     QString textid = qElement.attribute(QLatin1String("textid"), QLatin1String("-1"));
@@ -1389,10 +1402,10 @@ bool MessageWidget::loadFromXMI(QDomElement& qElement)
         if (tag == QLatin1String("floatingtext") || tag == QLatin1String("UML::FloatingTextWidget")) {
             m_pFText = new FloatingTextWidget(m_scene, tr, operationText(m_scene), m_textId);
             m_scene->addFloatingTextWidget(m_pFText);
-            if(! m_pFText->loadFromXMI(element)) {
+            if(! m_pFText->loadFromXMI1(element)) {
                 // Most likely cause: The FloatingTextWidget is empty.
                 delete m_pFText;
-                m_pFText = NULL;
+                m_pFText = 0;
             }
             else
                 m_pFText->setSequenceNumber(m_SequenceNumber);
