@@ -49,16 +49,18 @@ WidgetBase::WidgetBase(UMLScene *scene, WidgetType type)
     m_brush(m_fillColor),
     m_lineWidth(0), // initialize with 0 to have valid start condition
     m_useFillColor(true),
-    m_usesDiagramTextColor(true),
+    m_usesDiagramFillColor(true),
     m_usesDiagramLineColor(true),
-    m_usesDiagramLineWidth(true)
+    m_usesDiagramLineWidth(true),
+    m_usesDiagramTextColor(true),
+    m_usesDiagramUseFillColor(true),
+    m_autoResize(true)
 {
     Q_ASSERT(m_baseType > wt_MIN && m_baseType < wt_MAX);
     // Note: no virtual methods from derived classes available,
     // this operation need to be finished in derived class constructor.
     setLineColor(QColor("black"));
     setSelected(false);
-    scene->addItem(this);
 
     // TODO 310283
     setFlags(ItemIsSelectable);
@@ -476,6 +478,24 @@ void WidgetBase::setFont(const QFont& font)
     m_font = font;
 }
 
+/**
+ * Return state of auto resize property
+ * @return the auto resize state
+ */
+bool WidgetBase::autoResize()
+{
+    return m_autoResize;
+}
+
+/**
+ * set auto resize state
+ * @param state
+ */
+void WidgetBase::setAutoResize(bool state)
+{
+    m_autoResize = state;
+}
+
 /**
  * A virtual method for the widget to display a property dialog box.
  * Subclasses should reimplment this appropriately.
@@ -495,7 +515,7 @@ void WidgetBase::showPropertiesDialog()
  * @param qDoc A QDomDocument object representing the xml document.
  * @param qElement A QDomElement representing xml element data.
  */
-void WidgetBase::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
+void WidgetBase::saveToXMI1(QDomDocument& qDoc, QDomElement& qElement)
  {
     Q_UNUSED(qDoc)
 
@@ -521,6 +541,7 @@ void WidgetBase::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
         qElement.setAttribute(QLatin1String("fillcolor"), m_fillColor.name());
     }
     qElement.setAttribute(QLatin1String("font"), m_font.toString());
+    qElement.setAttribute(QLatin1String("autoresize"), m_autoResize ? 1 : 0);
 }
 
 /**
@@ -535,7 +556,7 @@ void WidgetBase::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
  *
  * @todo Add support to load older version.
  */
-bool WidgetBase::loadFromXMI(QDomElement& qElement)
+bool WidgetBase::loadFromXMI1(QDomElement& qElement)
 {
     // first load from "linecolour" and then overwrite with the "linecolor"
     // attribute if that one is present. The "linecolour" name was a "typo" in
@@ -595,6 +616,8 @@ bool WidgetBase::loadFromXMI(QDomElement& qElement)
         uWarning() << "Using default font " << m_font.toString()
                    << " for widget with xmi.id " << Uml::ID::toString(m_nId);
     }
+    QString autoResize = qElement.attribute(QLatin1String("autoresize"), QLatin1String("1"));
+    m_autoResize = (bool)autoResize.toInt();
 
     return true;
 }
@@ -796,7 +819,7 @@ void WidgetBase::slotMenuSelection(QAction *trigger)
             wt == WidgetBase::wt_Datatype  || wt == WidgetBase::wt_Node      ||
             wt == WidgetBase::wt_Component || wt == WidgetBase::wt_Artifact  ||
             wt == WidgetBase::wt_Enum      || wt == WidgetBase::wt_Entity    ||
-            wt == WidgetBase::wt_Port      ||
+            wt == WidgetBase::wt_Port      || wt == WidgetBase::wt_Instance ||
             (wt == WidgetBase::wt_Class && umlScene()->type() == Uml::DiagramType::Class)) {
 
             showPropertiesDialog();
@@ -1123,6 +1146,9 @@ QString WidgetBase::toI18nString(WidgetType wt)
     case wt_UseCase:
         name = i18n("UseCase");
         break;
+    case wt_Instance:
+        name = i18n("Instance");
+        break;
     default:
         name = QLatin1String("<unknown> &name:");
         uWarning() << "unknown widget type";
@@ -1131,6 +1157,114 @@ QString WidgetBase::toI18nString(WidgetType wt)
     return name;
 }
 
+/**
+ * Returns the given enum value as icon type.
+ * @param wt   WidgetType of which an icon type representation is wanted
+ * @return   the WidgetType as icon type
+ */
+Icon_Utils::IconType WidgetBase::toIcon(WidgetBase::WidgetType wt)
+{
+    Icon_Utils::IconType icon;
+
+    switch (wt) {
+    case wt_Activity:
+        icon = Icon_Utils::it_Activity;
+        break;
+    case wt_Actor:
+        icon = Icon_Utils::it_Actor;
+        break;
+    case wt_Artifact:
+        icon = Icon_Utils::it_Artifact;
+        break;
+    case wt_Association:
+        icon = Icon_Utils::it_Association;
+        break;
+    case wt_Box:
+        icon = Icon_Utils::it_Box;
+        break;
+    case wt_Category:
+        icon = Icon_Utils::it_Category;
+        break;
+    case wt_CombinedFragment:
+        icon = Icon_Utils::it_Combined_Fragment;
+        break;
+    case wt_Component:
+        icon = Icon_Utils::it_Component;
+        break;
+    case wt_Class:
+        icon = Icon_Utils::it_Class;
+        break;
+    case wt_Datatype:
+        icon = Icon_Utils::it_Datatype;
+        break;
+    case wt_Entity:
+        icon = Icon_Utils::it_Entity;
+        break;
+    case wt_Enum:
+        icon = Icon_Utils::it_Enum;
+        break;
+    case wt_FloatingDashLine:
+        icon = Icon_Utils::it_Association;
+        break;
+    case wt_ForkJoin:
+        icon = Icon_Utils::it_Fork_Join;
+        break;
+    case wt_Instance:
+        icon = Icon_Utils::it_Instance;
+        break;
+    case wt_Interface:
+        icon = Icon_Utils::it_Interface;
+        break;
+    case wt_Message:
+        icon = Icon_Utils::it_Message_Synchronous;
+        break;
+    case wt_Node:
+        icon = Icon_Utils::it_Node;
+        break;
+    case wt_Note:
+        icon = Icon_Utils::it_Note;
+        break;
+    case wt_Object:
+        icon = Icon_Utils::it_Object;
+        break;
+    case wt_ObjectNode:
+        icon = Icon_Utils::it_Object_Node;
+        break;
+    case wt_Package:
+        icon = Icon_Utils::it_Package;
+        break;
+    case wt_Pin:
+        icon = Icon_Utils::it_Pin;
+        break;
+    case wt_Port:
+        icon = Icon_Utils::it_Port;
+        break;
+    case wt_Precondition:
+        icon = Icon_Utils::it_Precondition;
+        break;
+    case wt_Region:
+        icon = Icon_Utils::it_Region;
+        break;
+    case wt_Signal:
+        icon = Icon_Utils::it_Send_Signal;
+        break;
+    case wt_State:
+        icon = Icon_Utils::it_State;
+        break;
+    case wt_Text:
+        icon = Icon_Utils::it_Text;
+        break;
+    case wt_UseCase:
+        icon = Icon_Utils::it_UseCase;
+        break;
+    default:
+        icon = Icon_Utils::it_Home;
+        uWarning() << "unknown widget type";
+        break;
+    }
+    return icon;
+}
+
 #include  "activitywidget.h"
 #include  "actorwidget.h"
 #include  "artifactwidget.h"
